<?php
/**
 * GutenBook Theme Customizer
 *
 * @package GutenBook
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function gutenbook_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'gutenbook_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'gutenbook_customize_partial_blogdescription',
			)
		);
	}

	$wp_customize->add_section(
		'gutenbook_hero_text',
		array(
			'title'    => __( 'GutenBook - Hero Text', 'gutenbook' ),
			'priority' => 40,
		)
	);

	$wp_customize->add_setting(
		'gutenbook_hero_title',
		array(
			'default'           => __( 'WordPress blog theme made for Gutenberg.', 'gutenbook' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'gutenbook_hero_title',
		array(
			'label'   => __( 'Hero Section Title', 'gutenbook' ),
			'type'    => 'text',
			'section' => 'gutenbook_hero_text',
			'setting' => 'gutenbook_hero_title',
		)
	);

	$wp_customize->add_setting(
		'gutenbook_hero_desc',
		array(
			'default'           => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi.', 'gutenbook' ),
			'sanitize_callback' => 'sanitize_textarea_field',
		)
	);

	$wp_customize->add_control(
		'gutenbook_hero_desc',
		array(
			'label'   => __( 'Sub-title on Cover Section', 'gutenbook' ),
			'type'    => 'textarea',
			'section' => 'gutenbook_hero_text',
			'setting' => 'gutenbook_hero_desc',
		)
	);

}
add_action( 'customize_register', 'gutenbook_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function gutenbook_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function gutenbook_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function gutenbook_customize_preview_js() {
	wp_enqueue_script( 'gutenbook-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'gutenbook_customize_preview_js' );
